@@ -26,10 +26,26 @@ except ImportError:
 import steve.restapi
 import steve.richardapi
 from steve.util import (
-    YOUTUBE_EMBED, with_config, BetterArgumentParser, wrap_paragraphs,
-    out, err, vidscraper_to_dict, ConfigNotFound, convert_to_json,
-    load_json_files, save_json_file, save_json_files, get_from_config,
-    verify_json_files, generate_filename)
+    BetterArgumentParser,
+    ConfigNotFound,
+    YOUTUBE_EMBED,
+    convert_to_json,
+    err,
+    fetch_videos_from_url,
+    generate_filename,
+    get_from_config,
+    get_project_config,
+    load_json_files,
+    out,
+    save_json_file,
+    save_json_files,
+    scrapevideo,
+    stringify,
+    verify_json_files,
+    vidscraper_to_dict,
+    with_config,
+    wrap_paragraphs,
+)
 from steve.webedit import serve
 
 
@@ -109,6 +125,12 @@ def fetch_cmd(cfg, parser, parsed, args):
     projectpath = cfg.get('project', 'projectpath')
     jsonpath = os.path.join(projectpath, 'json')
 
+    # source_url -> filename
+    source_map = dict(
+        (item['source_url'], fn)
+        for fn, item in load_json_files(cfg)
+    )
+
     if not os.path.exists(jsonpath):
         os.makedirs(jsonpath)
 
@@ -132,23 +154,24 @@ def fetch_cmd(cfg, parser, parsed, args):
         youtube_embed = None
 
     out('Scraping {0}...'.format(url))
-    video_feed = vidscraper.auto_feed(url)
-    video_feed.load()
+    videos = fetch_videos_from_url(url, youtube_embed)
 
-    print 'Found {0} videos...'.format(video_feed.video_count)
-    for i, video in enumerate(video_feed):
-        filename = generate_filename(video.title or '')
-        filename = '{index:04d}{basename}.json'.format(
+    print 'Found {0} videos...'.format(len(videos))
+    for i, video in enumerate(videos):
+        if video['source_url'] in source_map and not parsed.force:
+            print 'Skipping {0}... already exists.'.format(
+                stringify(video['title']))
+            continue
+
+        filename = generate_filename(video['title'])
+        filename = '{index:04d}_{basename}.json'.format(
             index=i, basename=filename[:40])
 
         print 'Working on {0}... ({1})'.format(
-            unicodedata.normalize('NFKD', video.title).encode(
-                'ascii', 'ignore'),
-            filename)
-        item = vidscraper_to_dict(video, youtube_embed=youtube_embed)
+            stringify(video['title']), filename)
 
         f = open(os.path.join('json', filename), 'w')
-        f.write(convert_to_json(item))
+        f.write(convert_to_json(video))
         f.close()
 
         # TODO: what if there's a file there already? on the first one,
@@ -235,8 +258,27 @@ def scrapevideo_cmd(parser, parsed, args):
         parser.print_byline()
 
     video_url = parsed.video[0]
-    print json.dumps(steve.scrapevideo(video_url), indent=2, sort_keys=True)
+    data = scrapevideo(video_url, parsed.richard, 'object')
+    if parsed.save:
+        cfg = get_project_config()
 
+        projectpath = cfg.get('project', 'projectpath')
+        jsonpath = os.path.join(projectpath, 'json')
+
+        if not os.path.exists(jsonpath):
+            os.makedirs(jsonpath)
+
+        fn = 'json/' + generate_filename(data['title']) + '.json'
+
+        if os.path.exists(fn):
+            err('It already exists!')
+            return 1
+
+        with open(fn, 'w') as fp:
+            fp.write(convert_to_json(data))
+        print 'Saved as {0}'.format(fn)
+    else:
+        print convert_to_json(data)
     return 0
 
 
@@ -285,8 +327,6 @@ def push_cmd(cfg, parser, parsed, args):
     # Go through and make sure there aren't any problems with
     # categories.
 
-    api = steve.restapi.API(api_url)
-
     all_categories = dict(
         [(cat['title'], cat)
          for cat in steve.richardapi.get_all_categories(api_url)])
@@ -298,7 +338,8 @@ def push_cmd(cfg, parser, parsed, args):
             err('Category "{0}" does not exist on server. Build it there '
                 'first.'.format(category))
             return 1
-
+        else:
+            out('Category {0} exists on site.'.format(category))
     except ConfigParser.NoOptionError:
         category = None
 
@@ -344,6 +385,7 @@ def push_cmd(cfg, parser, parsed, args):
     out('Username:   {0}'.format(username))
     out('api_key:    {0}'.format(api_key))
     out('update?:    {0}'.format(update))
+    out('# videos:   {0}'.format(len(data)))
     out('Once you push, you can not undo it. Push for realz? Y/N')
     if not raw_input().strip().lower().startswith('y'):
         err('Aborting.')
@@ -355,13 +397,15 @@ def push_cmd(cfg, parser, parsed, args):
         if not update:
             # Nix any id field since that causes problems.
             if 'id' in contents:
+                if not parsed.overwrite:
+                    print 'Skipping... already exists'
+                    continue
                 del contents['id']
 
             out('Pushing {0}'.format(fn))
             try:
-                vid = steve.restapi.get_content(
-                    api.video.post(contents, username=username,
-                                   api_key=api_key))
+                vid = steve.richardapi.create_video(api_url, api_key, contents)
+
                 if 'id' in vid:
                     contents['id'] = vid['id']
                     out('   Now has id {0}'.format(vid['id']))
@@ -375,9 +419,8 @@ def push_cmd(cfg, parser, parsed, args):
             out('Updating {0} "{1}" ({2})'.format(
                 contents['id'], contents['title'], fn))
             try:
-                vid = steve.restapi.get_content(
-                    api.video(str(contents['id'])).put(
-                        contents, username=username, api_key=api_key))
+                vid = steve.richardapi.update_video(
+                    api_url, api_key, contents['id'], contents)
             except steve.restapi.RestAPIException as exc:
                 err('   Error?: {0}'.format(exc))
                 err('   "{0}"'.format(exc.response.content))
@@ -494,6 +537,11 @@ def main(argv):
 
     fetch_parser = subparsers.add_parser(
         'fetch', help='fetches all the videos and generates .json files')
+    fetch_parser.add_argument(
+        '--force',
+        action='store_true',
+        default=False,
+        help='forces steve to stomp on existing files')
     fetch_parser.set_defaults(func=fetch_cmd)
 
     status_parser = subparsers.add_parser(
@@ -511,6 +559,16 @@ def main(argv):
 
     scrapevideo_parser = subparsers.add_parser(
         'scrapevideo', help='fetches metadata for a video from a site')
+    scrapevideo_parser.add_argument(
+        '--richard',
+        action='store_true',
+        default=False,
+        help='return richard JSON format')
+    scrapevideo_parser.add_argument(
+        '--save',
+        action='store_true',
+        default=False,
+        help='saves it to the filesystem using the title as the filename')
     scrapevideo_parser.add_argument(
         'video',
         nargs=1)
@@ -526,6 +584,11 @@ def main(argv):
         action='store_true',
         default=False,
         help='update data rather than push new data (PUT vs. POST)')
+    push_parser.add_argument(
+        '--overwrite',
+        action='store_true',
+        default=False,
+        help='if it exists, overwrite it')
     push_parser.set_defaults(func=push_cmd)
 
     pull_parser = subparsers.add_parser(
